@@ -25,7 +25,8 @@ l_fitBar <- function(a.aes = list(), ...){
 ######## Internal method for factor plots
 #' @noRd
 #'
-l_fitBar.PtermFactor <- l_fitBar.MultiPtermNumeric <- l_fitBar.MultiPtermFactor <- l_fitBar.ALE1DFactor <- function(a){
+l_fitBar.PtermFactor <- l_fitBar.MultiPtermNumeric <- l_fitBar.MultiPtermFactor <- 
+                        l_fitBar.ALE1DFactor <- l_fitBar.singleIndexInner1D <- function(a){
   
   a$data <- a$data$fit
   if( is.null(a$na.rm) ){ a$na.rm <- TRUE}
